from setuptools import setup

setup()

import subprocess
import sys


# from https://stackoverflow.com/questions/12332975/installing-python-module-within-code
#subprocess.check_call([sys.executable, "-m", "pip", "install", "pandas==1.1.5"])




